##  Activating the Extension
Admins can activate the AI agent extension. Follow these steps:
  1. In the administration area, go to Optional Features and Early Access.
  2. Choose Activate for the AI Agent extension.
  3. Review the changes that will apply to the workspace, then confirm your action.
